If x is a valid guess, it is added to game$guess and assessed
against the target word. Increments game$guess_count if a valid guess is made.
have_a_guess(x, game, allowed_words = NULL)the guess.
'wordler' game object (as generated by
new_wordler).
a character vector of valid words for the guess. x must be in this vector to be allowed. Defaults to words used by the WORDLE game online (?wordler::wordle_allowed) if not provided.
A 'wordler' game object.