keyboards: Keyboard layouts for printing a wordler game at the console.
Description
A list of keyboard layouts used to show letters known to be not in target
word, in the target word, and in the right position in the target word.
Each element must be a list having 3 items, each representing a row of a
keyboard layout.