Learn R Programming

wordler (version 0.3.1)

qdap_dict: All five-letter words from the Nettalk Corpus Syllable Data Set.

Description

A dataset containing all five-letter words from the Nettalk Corpus Syllable Data Set as returned by qdapDictionaries::dictionaries().

Usage

qdap_dict

Arguments

Format

A character vector of length 2488.