Learn R Programming

wordler (version 0.3.1)

update_letters_known_in_position: Establish which letters are known to be in the correct position in the target word

Description

For all items in game$guess, establishes the letters which are now known to be in the correct position in the target word. These are present as a character vector in game$letters_known_in_position in the returned object.

Usage

update_letters_known_in_position(game)

Arguments

game

'wordler' game object (as generated by new_wordler).

Value

A 'wordler' game object.