Learn R Programming

wordler (version 0.3.1)

wordle_allowed: All words used to validate guesses by the original WORDLE game.

Description

A dataset containing all words which are used to validate guesses by the original WORDLE game. Note that this does not include the words which can be answers. Theses are held in ?wordle_answers.

Usage

wordle_allowed

Arguments

Format

A character vector of length 10657.