Learn R Programming

wordler (version 0.3.1)

wordle_answers: All words used as potential answers by the original WORDLE game.

Description

A dataset containing all words which can be used as answers to the original WORDLE game.

Usage

wordle_answers

Arguments

Format

A character vector of length 2315.